import React from 'react'

import { Box, Button, Divider, HStack, Text, VStack } from '@chakra-ui/react'

import { useParams } from '@redwoodjs/router'

import { Animations } from 'src/pages/animations'
import { Implementations } from 'src/pages/implementations'
import { GetPatternQuery } from '../query-builder'
import { RemovePatternButton } from '../remove-pattern'
import { FormalizationList } from './formalizations-list'

export const PatternDetails: React.FC = () => {
  const { id } = useParams()

  const getPatternQuery = GetPatternQuery.useQuery({ id })

  const pattern = getPatternQuery.data

  if (!pattern) {
    return null
  }

  return (
    <VStack w="full">
      <VStack w="80%">
        <VStack display="flex" alignItems="start" px="2" minW="80vw">
          <Text fontWeight="bold" fontSize="x-large">
            {pattern.name}
          </Text>
          <Text wordBreak="break-word">{pattern.description}</Text>
        </VStack>
        <VStack w="full" justifyContent="center" spacing="8">
          <VStack alignItems="flex-start">
            <Text pl="2" fontWeight="bold">
              Implementaciones
            </Text>
            <Implementations patternId={pattern.id} />
          </VStack>
          <VStack alignItems="flex-start">
            <Text pl="2" fontWeight="bold">
              Animaciones
            </Text>
            <Animations patternId={pattern.id} />
          </VStack>
        </VStack>
        <Divider py="4" />
        <VStack w="full" alignItems="flex-start">
          <Text fontWeight="bold">Formalizaciones</Text>
          <FormalizationList
            formalizations={pattern.formalizations}
            patternId={pattern.id}
          />
        </VStack>
        <Divider py="4" />
        <Box w="full" display="flex" justifyContent="flex-end" py="4">
          <RemovePatternButton pattern={pattern}>
            <Button colorScheme="red">Eliminar patron</Button>
          </RemovePatternButton>
        </Box>
      </VStack>
    </VStack>
  )
}
