import React from 'react'

import {
  HStack,
  Icon,
  IconButton,
  Table,
  TableCaption,
  TableContainer,
  Tbody,
  Td,
  Text,
  Th,
  Thead,
  Tooltip,
  Tr,
  VStack,
} from '@chakra-ui/react'
import { useParams } from '@redwoodjs/router'
import { GetImplementationQuery } from '../implementations/query-builder/get-implementation-query'
import { GetReportsByImplementationIdQuery } from './query-builder'
import { DateUtils } from 'src/utils/date-utils'
import { Report } from 'src/models'
import { FaEye } from 'react-icons/fa'

const tableHeaders = ['Fecha', 'Nombre', '']

export const Reports = () => {
  const { implementationId } = useParams()

  const implementationQuery = GetImplementationQuery.useQuery({
    id: implementationId,
  })

  const reportsQuery = GetReportsByImplementationIdQuery.useQuery({
    id: implementationId,
  })

  return (
    <VStack alignItems="flex-start" spacing="2">
      <Text fontWeight="bold" fontSize="x-large" px="1">
        Reportes de implementacion {implementationQuery.data?.name}
      </Text>
      <TableContainer>
        <Table variant="striped" size="lg" minW="80vw">
          <TableCaption>Reportes disponibles</TableCaption>
          <Thead>
            <Tr>
              {tableHeaders.map((header, index) => (
                <Th color="gray.500" key={`th-${index}`}>
                  {header}
                </Th>
              ))}
            </Tr>
          </Thead>
          <Tbody>
            {reportsQuery.data?.map((report, index) => (
              <Tr key={`report-${report.name}-${index}`}>
                <Td>{DateUtils.formatLocalDateTime(report.createdDate)}</Td>
                <Td>{report.name}</Td>
                <Td>
                  <ActionsRow report={report} />
                </Td>
              </Tr>
            ))}
          </Tbody>
        </Table>
      </TableContainer>
    </VStack>
  )
}

type ActionsRowProps = {
  report: Report
}

const ActionsRow: React.FC<ActionsRowProps> = ({ report }) => {
  return (
    <HStack justifyContent="flex-end">
      <Tooltip shouldWrapChildren hasArrow label={<Text>Ver detalles</Text>}>
        <IconButton
          aria-label="ver detalles de reporte"
          variant="unstyled"
          icon={<Icon as={FaEye} />}
        />
      </Tooltip>
    </HStack>
  )
}
